# Arrays, Matrices and Linear Algebra

The main feature of LibRapid is its high-performance array library. It provides an intuitive way to perform
highly efficient operations on arrays and matrices in C++.

```{toctree}
Linear Algebra <linalg/linalg.md>
Array Listing <arrayListing.md>
From Data <fromData.md>
Pseudoconstructors <pseudoconstructors.md>
Iterators <iterators.md>
Array View <arrayView.md>
Array Operations <arrayOperations.md>
Size Type <sizeType.md>
Stride Tools <strideTools.md>
Storage <storage.md>
OpenCL Storage <openclStorage.md>
CUDA Storage <cudaStorage.md>
```
